Name:		shared-mime-info
Version:	2.4
Release:	%mkrel 3
Summary:	Shared MIME-Info Specification
Group:		Graphical desktop/Other
#gw main is GPL, test program is LGPL
License:	GPL+ and LGPLv2+
URL:		https://www.freedesktop.org/wiki/Software/shared-mime-info
Source0:	https://gitlab.freedesktop.org/xdg/shared-mime-info/-/archive/%{version}/%{name}-%{version}.tar.gz
####
#### Fedora:
####
Source1:	mimeapps.list

# Tarball for https://gitlab.freedesktop.org/xdg/xdgmime/-/tree/179296748e92bd91bf531656632a1056307fb7b7
Source6:	https://gitlab.freedesktop.org/xdg/xdgmime/-/archive/master/xdgmime-master.tar.gz

# Mageia KDE overrides.
Source20:	plasma-mimeapps.list

# Work-around for https://bugs.freedesktop.org/show_bug.cgi?id=40354
Patch0:		0001-Remove-sub-classing-from-OO.o-mime-types.patch

Patch100:	shared-mime-info-xz.patch

BuildRequires:	pkgconfig(libxml-2.0)
BuildRequires:	xmlto
BuildRequires:	pkgconfig(glib-2.0)
BuildRequires:	intltool
BuildRequires:	itstool
BuildRequires:	libxml2-utils
BuildRequires:	meson
Provides:	gnome-mime-data
Conflicts:	cinnamon-desktop < 4.0.1-4
Conflicts:	mageia-kde4-config-common < 5-0.20150505.13

# Disable pkgconfig autodep
%global __requires_exclude ^/usr/bin/pkg-config$

%description
This is the freedesktop.org shared MIME info database.

Many programs and desktops use the MIME system to represent the types of
files. Frequently, it is necessary to work out the correct MIME type for
a file. This is generally done by examining the file's name or contents,
and looking up the correct MIME type in a database.

For interoperability, it is useful for different programs to use the
same database so that different programs agree on the type of a file,
and new rules for determining the type apply to all programs.

This specification attempts to unify the type-guessing systems currently
in use by GNOME, KDE and ROX. Only the name-to-type and contents-to-type
mappings are covered by this spec; other MIME type information, such as
the default handler for a particular type, or the icon to use to display
it in a file manager, are not covered since these are a matter of style.

In addition, freedesktop.org provides a shared database in this format
to avoid inconsistencies between desktops. This database has been
created by converting the existing KDE and GNOME databases to the new
format and merging them together.

%prep
%setup -q
%patch0 -p1
%patch100 -p1

rmdir xdgmime
tar -xzf %{SOURCE6}
mv xdgmime-*/ xdgmime/

%build
%make_build -C xdgmime || :
# the updated mimedb is later owned as %%ghost to ensure proper file-ownership
# it also asserts it is possible to build it
%meson -Dupdate-mimedb=true
%meson_build

%install
%meson_install

find %{buildroot}%{_datadir}/mime -type d \
| sed -e "s|^%{buildroot}|%%dir |" > %{name}.files
find %{buildroot}%{_datadir}/mime -type f -not -path "*/packages/*" \
| sed -e "s|^%{buildroot}|%%ghost |" >> %{name}.files

# install mimeapps.list files
mkdir -p %{buildroot}%{_datadir}/applications
install -pm644 %{SOURCE1} %{SOURCE20} %{buildroot}%{_datadir}/applications
cp -p %{buildroot}%{_datadir}/applications/plasma-mimeapps.list %{buildroot}%{_datadir}/applications/kde-mimeapps.list

## remove bogus translation files
## translations are already in the xml file installed
rm -rf %{buildroot}%{_datadir}/locale/*

# fix x-rpm entry
sed -i 's!application/x-rpm=.*!application/x-rpm=%{_real_vendor}-gurpmi.desktop;gurpmi.desktop;!' \
	%{buildroot}%{_datadir}/applications/mimeapps.list

## Xfce starts
sed \
    -e 's,brasero,xfburn,g' \
    -e 's,evolution,exo-mail-reader,g' \
    -e 's,firefox,exo-web-browser,g' \
    -e 's,org.gnome.eog,org.xfce.ristretto,g' \
    -e 's,org.gnome.Evince,atril,g' \
    -e 's,org.gnome.FileRoller,engrampa,g' \
    -e 's,org.gnome.gedit,org.xfce.mousepad,g' \
    -e 's,org.gnome.Nautilus,exo-file-manager,g' \
    -e 's,org.gnome.Rhythmbox3,org.xfce.Parole.desktop,g' \
    -e 's,org.gnome.Totem,org.xfce.Parole.desktop,g' \
    %{buildroot}%{_datadir}/applications/mimeapps.list >> %{buildroot}%{_datadir}/applications/xfce-mimeapps.list
## Xfce ends

## Cinnamon
# $XDG_CURRENT_DESKTOP in cinnamon is X-Cinnamon
sed -e 's,\(eog.desktop\),pix.desktop;\1,g' \
    -e 's,\(org.gnome.Evince.desktop\),xreader.desktop;\1,g' \
    -e 's,\(org.gnome.gedit.desktop\),xed.desktop;\1,g' \
    -e 's,\(org.gnome.Totem.desktop\),xplayer.desktop;\1,g' \
    -e 's,org.gnome.Nautilus,nemo,g' \
    %{buildroot}%{_datadir}/applications/mimeapps.list >> %{buildroot}%{_datadir}/applications/x-cinnamon-mimeapps.list
## Cinnamon ends

%check
%meson_test

%post
/bin/touch --no-create %{_datadir}/mime/packages &>/dev/null ||:

# automatic mime database update on rpm installs/removals
%transfiletriggerin -- %{_datadir}/mime
update-mime-database -n %{_datadir}/mime &> /dev/null ||:

%transfiletriggerpostun -- %{_datadir}/mime
update-mime-database -n %{_datadir}/mime &> /dev/null ||:

%files -f %{name}.files
%doc README.md data/shared-mime-info-spec.xml NEWS
%{_bindir}/update-mime-database
%{_datadir}/applications/kde-mimeapps.list
%{_datadir}/applications/plasma-mimeapps.list
%{_datadir}/applications/mimeapps.list
%{_datadir}/applications/x-cinnamon-mimeapps.list
%{_datadir}/applications/xfce-mimeapps.list
%{_datadir}/mime/packages/freedesktop.org.xml
%{_mandir}/man1/update-mime-database.1*
%{_datadir}/pkgconfig/shared-mime-info.pc
%{_datadir}/gettext/its/shared-mime-info.its
%{_datadir}/gettext/its/shared-mime-info.loc


%changelog
* Sat Apr 06 2024 wally <wally> 2.4-3.mga10
+ Revision: 2055202
- basesystem rebuild for i686

* Sun Mar 03 2024 daviddavid <daviddavid> 2.4-2.mga10
+ Revision: 2047358
- fix for xfce brasero -> xfburn

* Sat Mar 02 2024 daviddavid <daviddavid> 2.4-1.mga10
+ Revision: 2046810
- new version: 2.4
- drop no more available rhythmbox.desktop mimeapps
- fix for brasero, dia, packagekit, gnumeric, gnucash and shotwell mimeapps
- replace clementine with strawberry as media player for plasma
- fix for gurpmi and kfmclient_html mimeapps

* Tue Oct 31 2023 daviddavid <daviddavid> 2.3-1.mga10
+ Revision: 2002987
- new version: 2.3

* Sat Feb 18 2023 ghibo <ghibo> 2.2-5.mga9
+ Revision: 1943983
- Merge kde-mimeapps from mageia-kde4-config.
- Add Conflicts (fix bug #31560).

* Thu Feb 16 2023 ghibo <ghibo> 2.2-4.mga9
+ Revision: 1943376
- Added multiple entries for Plasma for when the main application is missed or removed.

* Wed Feb 15 2023 ghibo <ghibo> 2.2-3.mga9
+ Revision: 1942597
- Add more mime types for plasma.
- Fix files list.

* Sun Dec 11 2022 wally <wally> 2.2-2.mga9
+ Revision: 1920542
- fix Xfce mimeapps

* Thu Jun 09 2022 tv <tv> 2.2-1.mga9
+ Revision: 1863686
- 2.2 (fix build)
- Drop unknown xdg-mime-path option
- Prevent deps on pkg-config, thus unbloating minimal installation
+ papoteur <papoteur>
- Replace hexchat with konversation as IRC client for plasma
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Sat Jan 02 2021 luigiwalser <luigiwalser> 2.1-2.mga8
+ Revision: 1668117
- 2.1
- update source URLs
- update xdgmime to git tarball as of 20201230
- remove patch 1 (fixed upstream)

* Thu Nov 19 2020 luigiwalser <luigiwalser> 2.0-2.mga8
+ Revision: 1647430
- rename source20 again to plasma-mimeapps.list, fixing conflict with mageia-kde4-config-common

* Wed Nov 18 2020 luigiwalser <luigiwalser> 2.0-1.mga8
+ Revision: 1647351
- 2.0
- rename source1 to mimeapps.list
- rename source20 to kde-mimeapps.list
- add xdgmime snapshot tarball from upstream via fedora
- update patch0 from fedora
- add patch1 from fedora to fix pkgconfig installation path
- switch to meson build system

* Tue Feb 18 2020 umeabot <umeabot> 1.15-2.mga8
+ Revision: 1541701
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Tue Dec 31 2019 wally <wally> 1.15-1.mga8
+ Revision: 1475046
- new version 1.15

* Sat Apr 27 2019 wally <wally> 1.12-7.mga7
+ Revision: 1395732
- fix file manager in cinnamon mimeapps.list

* Sat Apr 27 2019 wally <wally> 1.12-6.mga7
+ Revision: 1395721
- create cinnamon's mimeapps.list based on gnome's
- fix totem entry in gnome-mimeapps.list

* Sat Apr 27 2019 wally <wally> 1.12-5.mga7
+ Revision: 1395706
- add mimeapps.list for cinnamon (move from cinnamon-desktop)
- prefer evince after xreader in cinnamon for text document etc. (mga#24700)

* Sun Feb 10 2019 wally <wally> 1.12-4.mga7
+ Revision: 1365030
- update xfce-mimeapps.list based on gnome-mimeapps.list
- handle fixing x-rpm entry with sed magic

* Sun Jan 20 2019 luigiwalser <luigiwalser> 1.12-3.mga7
+ Revision: 1358375
- implement local modification for gurpmi as a patch

* Sat Jan 19 2019 tmb <tmb> 1.12-2.mga7
+ Revision: 1358145
- restore gurpmi support

* Sat Jan 19 2019 luigiwalser <luigiwalser> 1.12-1.mga7
+ Revision: 1358115
- 1.12
- source URL will always change now
- remove patch for generated file from patch 100
- add defaults for evince so comic books do not open in File Roller by default
  (from fedora)
- resync gnome-mimeapps.list from fedora

* Sun Oct 21 2018 daviddavid <daviddavid> 1.10-1.mga7
+ Revision: 1323343
- new version: 1.10

* Sun Sep 23 2018 umeabot <umeabot> 1.9-2.mga7
+ Revision: 1301014
- Mageia 7 Mass Rebuild

* Mon Feb 05 2018 daviddavid <daviddavid> 1.9-1.mga7
+ Revision: 1198995
- new version: 1.9

* Wed Sep 13 2017 cjw <cjw> 1.8-2.mga7
+ Revision: 1153356
- make post script run update-mime-database so mime.cache exists after install

* Sun Jan 01 2017 luigiwalser <luigiwalser> 1.8-1.mga6
+ Revision: 1078992
- 1.8

* Wed Sep 21 2016 ovitters <ovitters> 1.7-3.mga6
+ Revision: 1055033
- set hexchat as default IRC handler (exception for GNOME in place; Plasma pending) (mga#19346)

* Wed Sep 21 2016 ovitters <ovitters> 1.7-2.mga6
+ Revision: 1055000
- GNOME: Default to Polari for IRC
- GNOME: fix some Totem defaults

* Fri Sep 09 2016 luigiwalser <luigiwalser> 1.7-1.mga6
+ Revision: 1051185
- 1.7
- update patch 0 from fedora

* Wed Aug 03 2016 tv <tv> 1.6-3.mga6
+ Revision: 1044323
- emergency provides gnome-mime-data

* Tue Aug 02 2016 ovitters <ovitters> 1.6-2.mga6
+ Revision: 1044303
- obsolete gnome-mime-data

* Mon May 09 2016 luigiwalser <luigiwalser> 1.6-1.mga6
+ Revision: 1011564
- 1.6
- rediff xz patch
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Tue Nov 17 2015 blino <blino> 1.5-1.mga6
+ Revision: 903909
- 1.5
- drop backported patch for .iso files (included upstream)

* Sun Sep 06 2015 tv <tv> 1.4-7.mga6
+ Revision: 873172
- switch to new upstream file trigger syntax

* Sat Jun 20 2015 wally <wally> 1.4-6.mga6
+ Revision: 836651
- update xfce-mimeapps.list

* Sun Mar 22 2015 doktor5000 <doktor5000> 1.4-5.mga5
+ Revision: 819084
- revert latest broken upstream fix and reuse previous patch (mga#13989)

* Thu Feb 19 2015 doktor5000 <doktor5000> 1.4-4.mga5
+ Revision: 815845
- replace workaround for (fd.o#80877) (mga#13989) by upstream fix

* Wed Feb 18 2015 wally <wally> 1.4-3.mga5
+ Revision: 815552
- create own xfce-mimeapps.list for Xfce

* Tue Feb 17 2015 doktor5000 <doktor5000> 1.4-2.mga5
+ Revision: 815402
- add fix for .iso image recognition (fd.o#80877) (mga#13989)

* Fri Feb 13 2015 luigiwalser <luigiwalser> 1.4-1.mga5
+ Revision: 814849
- 1.4
- remove upstreamed patches
- rediff remaining patches

* Mon Jan 05 2015 ovitters <ovitters> 1.3-6.mga5
+ Revision: 808514
- kill defaults.list and introduce gnome-mimeapps.list per dev ml discussion

* Tue Nov 25 2014 tv <tv> 1.3-5.mga5
+ Revision: 799238
- sync with FC (mga#14655)
- set gurpmi with sed

* Wed Oct 15 2014 umeabot <umeabot> 1.3-4.mga5
+ Revision: 746096
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.3-3.mga5
+ Revision: 689133
- Mageia 5 Mass Rebuild

* Sat Sep 13 2014 ovitters <ovitters> 1.3-2.mga5
+ Revision: 675128
- sync renamed GNOME desktop files

* Sat Apr 26 2014 luigiwalser <luigiwalser> 1.3-1.mga5
+ Revision: 618319
- 1.3

* Sun Dec 08 2013 colin <colin> 1.2-3.mga4
+ Revision: 555987
- Replace old nautilus .desktop names with current ones (or remove) mga#9110

* Mon Oct 21 2013 umeabot <umeabot> 1.2-2.mga4
+ Revision: 539196
- Mageia 4 Mass Rebuild

* Fri Oct 04 2013 luigiwalser <luigiwalser> 1.2-1.mga4
+ Revision: 491567
- 1.2

* Sun May 26 2013 ovitters <ovitters> 1.1-1.mga4
+ Revision: 428105
- rediff patch
- new version 1.1

* Mon Jan 14 2013 umeabot <umeabot> 1.0-3.mga3
+ Revision: 381961
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Jun 17 2012 fwang <fwang> 1.0-2.mga3
+ Revision: 261139
- fix bug#5665: msooxml files should be opened with libreoffice

* Sun Jan 22 2012 fwang <fwang> 1.0-1.mga2
+ Revision: 199756
- new version 1.0

* Wed Jan 11 2012 ovitters <ovitters> 0.91-2.mga2
+ Revision: 195021
- add patch from git to fix ppm detection (for gnome-boxes)

* Mon Sep 19 2011 fwang <fwang> 0.91-1.mga2
+ Revision: 145336
- rediff xz patch
- new version 0.91

* Tue Apr 26 2011 ahmad <ahmad> 0.90-5.mga1
+ Revision: 91844
- mimeapps.list: add application/x-rpm=mageia-gurpmi.desktop, so that it works
  for dolphin (and for Gvfs/GIO based apps)

* Tue Apr 26 2011 ahmad <ahmad> 0.90-4.mga1
+ Revision: 91244
- defaults.list: change the default application for application/x-rpm to
  mageia-gurpmi.desktop instead of the non-existent mandriva-gurpmi.desktop (mga#992)

* Thu Mar 24 2011 boklm <boklm> 0.90-3.mga1
+ Revision: 76208
- rebuild for bug #497

* Mon Mar 21 2011 ahmad <ahmad> 0.90-2.mga1
+ Revision: 75298
- disable parallel make, it fails with > -j2
- add x-scheme-handler/http* to defaults.list, so that gvfs-open can work with
  https links, should fix (mga#400)
- re-enable parallel make, seems to work now

* Sat Jan 15 2011 dmorgan <dmorgan> 0.90-1.mga1
+ Revision: 18268
- Add comment
- imported package shared-mime-info


* Fri Dec 03 2010 Götz Waschk <waschk@mandriva.org> 0.90-1mdv2011.0
+ Revision: 606053
- new version
- rediff patch 0
- disable parallel make

* Sat Oct 02 2010 Götz Waschk <waschk@mandriva.org> 0.80-1mdv2011.0
+ Revision: 582514
- new version
- rediff patches

* Wed Feb 03 2010 Götz Waschk <waschk@mandriva.org> 0.71-1mdv2010.1
+ Revision: 499880
- new version
- rediff the patches
- update license

* Sun Oct 25 2009 Götz Waschk <waschk@mandriva.org> 0.70-5mdv2010.0
+ Revision: 459265
- replace writer64 by writer in KDE mimeapps as well
- remove openoffice.org64 from defaults list (bug #54878)

* Mon Oct 12 2009 Nicolas Lécureuil <nlecureuil@mandriva.com> 0.70-4mdv2010.0
+ Revision: 456873
- Remove conflicts
- Remove the versionnate buildrequire and add a conflicts

* Thu Oct 08 2009 Nicolas Lécureuil <nlecureuil@mandriva.com> 0.70-2mdv2010.0
+ Revision: 455993
- Versionnate buildrequire

* Wed Oct 07 2009 Nicolas Lécureuil <nlecureuil@mandriva.com> 0.70-1mdv2010.0
+ Revision: 455557
- Update to version 0.70 ( Recommended by KDE )
  Rediff patches

* Fri Apr 24 2009 Götz Waschk <waschk@mandriva.org> 0.60-3mdv2010.0
+ Revision: 368966
- replace kpdf by ocular (bug #47658)

* Fri Apr 17 2009 Helio Chissini de Castro <helio@mandriva.com> 0.60-2mdv2009.1
+ Revision: 367913
- Add xz on the list of mimetypes

* Thu Feb 26 2009 Götz Waschk <waschk@mandriva.org> 0.60-1mdv2009.1
+ Revision: 345050
- new version
- drop patch 5

  + Frederik Himpe <fhimpe@mandriva.org>
    - Use Evince instead of tetex-xdvi for application/x-dvi

* Mon Oct 20 2008 Götz Waschk <waschk@mandriva.org> 0.51-4mdv2009.1
+ Revision: 295632
- update patch 5 with generic icon support

* Fri Sep 05 2008 Helio Chissini de Castro <helio@mandriva.com> 0.51-3mdv2009.0
+ Revision: 281444
- Added firefox as addition in the mimeapps.list, so kde can use firefox as default browser for applicatin/xml+html and text/html
  Thi solution not breaks konqueror navigation as well, so the konqueror usage remains the same
- Updated same mimes for defaults.list

* Fri Aug 08 2008 Götz Waschk <waschk@mandriva.org> 0.51-2mdv2009.0
+ Revision: 268246
- remove totem from the cd player list

* Thu Jul 31 2008 Frederic Crozat <fcrozat@mandriva.com> 0.51-1mdv2009.0
+ Revision: 257716
- Release 0.51
- Rengerate patch5

* Thu Jun 12 2008 Frederic Crozat <fcrozat@mandriva.com> 0.40-1mdv2009.0
+ Revision: 218370
- Release 0.40

* Wed Jun 11 2008 Pixel <pixel@mandriva.com> 0.30-2mdv2009.0
+ Revision: 217913
- add rpm filetrigger running update-mime-database when rpm install/remove a mime file

* Mon May 19 2008 Götz Waschk <waschk@mandriva.org> 0.30-1mdv2009.0
+ Revision: 208896
- new version
- update URL
- drop patch 2
- update patch 4

* Fri Mar 21 2008 Frederic Crozat <fcrozat@mandriva.com> 0.23-2mdv2008.1
+ Revision: 189424
- Update default applications list and add autorun applications for hotplugged medias / devices

* Thu Jan 17 2008 Götz Waschk <waschk@mandriva.org> 0.23-1mdv2008.1
+ Revision: 153974
- new version
- drop patches 0,3

* Tue Jan 08 2008 Götz Waschk <waschk@mandriva.org> 0.22-6mdv2008.1
+ Revision: 146378
- add kpdf for pdf files

* Thu Jan 03 2008 Götz Waschk <waschk@mandriva.org> 0.22-5mdv2008.1
+ Revision: 141776
- add some MIME types from Office 2007

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Tue Oct 23 2007 Götz Waschk <waschk@mandriva.org> 0.22-4mdv2008.1
+ Revision: 101428
- fix bug #34988 (html files identified as mozilla bookmarks)

* Thu Sep 20 2007 Götz Waschk <waschk@mandriva.org> 0.22-3mdv2008.0
+ Revision: 91373
- fix entries for OO.o in defaults.list

* Thu Sep 13 2007 Frederic Crozat <fcrozat@mandriva.com> 0.22-2mdv2008.0
+ Revision: 85071
- Patch3 (CVS): various bug fixes
- Patch4: fix VHDL vs CRT magic detection (Mdv bug #31603)

* Mon Jul 30 2007 Götz Waschk <waschk@mandriva.org> 0.22-1mdv2008.0
+ Revision: 56517
- new version
- drop patches 3,4

  + Frederic Crozat <fcrozat@mandriva.com>
    - Update patch 4 with additional aliases

* Fri Jul 27 2007 Frederic Crozat <fcrozat@mandriva.com> 0.21-4mdv2008.0
+ Revision: 56360
- Patch3 (CVS): add video/avi as alias to video/x-msvideo
- Patch4 : add additional Ogg mimetypes / extensions
- Add totem as default player for ogg files

* Sun Jul 15 2007 Per Øyvind Karlsen <peroyvind@mandriva.org> 0.21-3mdv2008.0
+ Revision: 52240
- add lzma to defaults.list
- update lzma patch (P2) with pattern for tar archives as well

* Wed May 16 2007 Frederic Crozat <fcrozat@mandriva.com> 0.21-2mdv2008.0
+ Revision: 27313
- Set nautilus-cd-burner before file-roller as default application for ISO file (Mdv bug #30833)

* Tue Apr 24 2007 Götz Waschk <waschk@mandriva.org> 0.21-1mdv2008.0
+ Revision: 17740
- new version
- drop merged patches 0,1


* Fri Mar 30 2007 Frederic Crozat <fcrozat@mandriva.com> 0.20-6mdv2007.1
+ Revision: 149882
- Update defaults.list : add more mimetype, use totem instead of rhythmbox by
  default for audio files (Mdv bug #24022), it works best for not imported files

* Sun Mar 11 2007 Götz Waschk <waschk@mandriva.org> 0.20-5mdv2007.1
+ Revision: 141290
- add lzma

* Sun Mar 04 2007 Götz Waschk <waschk@mandriva.org> 0.20-4mdv2007.1
+ Revision: 132700
- fix upgrade

* Fri Mar 02 2007 Frederic Crozat <fcrozat@mandriva.com> 0.20-3mdv2007.1
+ Revision: 131454
- Patch1: resync with ufraw for raw digicam format

  + Thierry Vignaud <tvignaud@mandriva.com>
    - no need to package big ChangeLog when NEWS is already there

* Wed Feb 28 2007 Frederic Crozat <fcrozat@mandriva.com> 0.20-2mdv2007.1
+ Revision: 127085
-Remove patch16, it is networkmanager specific
-generate real patch to output correct type for RealVideo (fdo bug #10122) and no longer subclass them as text/plain
-Fix defaults.list for Real types

* Thu Feb 08 2007 Götz Waschk <waschk@mandriva.org> 0.20-1mdv2007.1
+ Revision: 117749
- new version
- drop merged patches 0 and 2
- update file list

* Mon Jan 22 2007 Götz Waschk <waschk@mandriva.org> 0.19-3mdv2007.1
+ Revision: 111706
- Import shared-mime-info

* Mon Jan 22 2007 Götz Waschk <waschk@mandriva.org> 0.19-3mdv2007.1
- add alias image/pdf for pdf documents
- unpack patches

* Fri Sep 15 2006 Frederic Crozat <fcrozat@mandriva.com> 0.19-2mdv2007.0
- Patch7: fix detection of Real files

* Sat Sep 09 2006 Frederic Crozat <fcrozat@mandriva.com> 0.19-1mdv2007.0
- New version 0.19 (goetz)
- fix URL
- drop patches 3,4,5,7
- clean defaults.list

* Tue Jul 04 2006 Frederic Crozat <fcrozat@mandriva.com> 0.18-1mdv2007.0
- Release 0.18
- Remove patches 0, 1, 8 (merged upstream)
- Regenerate patch2

* Fri Apr 14 2006 Götz Waschk <waschk@mandriva.org> 0.17-3mdk
- include Fedora patches

* Wed Mar 22 2006 Götz Waschk <waschk@mandriva.org> 0.17-2mdk
- improve patch 1
- patch 5: remove directory alias that was breaking nautilus

* Mon Mar 20 2006 Götz Waschk <waschk@mandriva.org> 0.17-1mdk
- add mime.cache
- rediff patch 1
- New release 0.17
- use mkrel

* Thu Sep 01 2005 Frederic Crozat <fcrozat@mandriva.com> 0.16-3mdk 
- Patch4: add powerpoint alias (Mdk bug #17645)

* Sat Jul 09 2005 Götz Waschk <waschk@mandriva.org> 0.16-2mdk
- update patch 1 to add WMA audio

* Tue Apr 19 2005 Götz Waschk <waschk@linux-mandrake.com> 0.16-1mdk
- drop patch 4
- New release 0.16

* Fri Mar 04 2005 Frederic Crozat <fcrozat@mandrakesoft.com> 0.15-3mdk 
- Source1: defaults applications to use for GNOME (based on Fedora)
- Patch4 (CVS): various fixes

* Fri Oct 01 2004 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 0.15-2mdk
- lib64 fixes to pkgconfig files

* Thu Sep 02 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 0.15-1mdk
- Release 0.15
- Remove postun script, let rpm do its job

* Wed Aug 18 2004 Götz Waschk <waschk@linux-mandrake.com> 0.14-5mdk
- update patch1 to make wmv an alias of asf

* Tue Aug 03 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 0.14-4mdk
- Patch2 : add glob for palm databases

* Sun May 16 2004 Götz Waschk <waschk@linux-mandrake.com> 0.14-3mdk
- fix asf, wmv and asx

* Sat Apr 17 2004 Götz Waschk <waschk@linux-mandrake.com> 0.14-2mdk
- fix dia magic detection (Hamish Mackenzie)

* Sat Apr 03 2004 Götz Waschk <waschk@linux-mandrake.com> 0.14-1mdk
- add pkgconfig file
- drop patch (fixed upstream)
- fix url
- new version

